
(_users_guide)=
# Users Guide


[Example Library](examples/main.md)
: Collection of examples using `skretrieval`

[In-depth Concepts](concepts/main.md)
: More detailed descriptions of each of the components of `skretrieval`

[Library Functionality](lib/main.md)
: Guides on how to use the various library functionality of `skretrieval` such as defining lineshapes


```{toctree}
:maxdepth: 4
:hidden:

examples/main.md
concepts/main.md
lib/main.md

```
